"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var couchbase_plugin_common_1 = require("./couchbase-plugin.common");
var utils = require("tns-core-modules/utils/utils");
var Couchbase = (function (_super) {
    __extends(Couchbase, _super);
    function Couchbase(name) {
        var _this = _super.call(this, name) || this;
        _this.config = new com.couchbase.lite.DatabaseConfiguration(utils.ad.getApplicationContext());
        _this.android = new com.couchbase.lite.Database(name, _this.config);
        return _this;
    }
    Couchbase.prototype.createDocument = function (data, documentId) {
        var doc;
        if (documentId) {
            doc = new com.couchbase.lite.MutableDocument(documentId);
        }
        else {
            doc = new com.couchbase.lite.MutableDocument();
        }
        var keys = Object.keys(data);
        for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
            var key = keys_1[_i];
            var item = data[key];
            doc.setValue(key, item);
        }
        this.android.save(doc);
        return doc.getId();
    };
    Couchbase.prototype.getDocument = function (documentId) {
        var doc = this.android.getDocument(documentId);
        var keys = doc.getKeys();
        var size = keys.size();
        var object = {};
        for (var i = 0; i < size; i++) {
            var key = keys[i];
            var item = doc.getValue(key);
            var newItem = {};
            newItem[key] = item;
            object = Object.assign(object, newItem);
        }
        return object;
    };
    Couchbase.prototype.updateDocument = function (documentId, data) {
        var origin = this.android.getDocument(documentId);
        if (origin) {
            var doc = origin.toMutable();
            var keys = Object.keys(data);
            for (var _i = 0, keys_2 = keys; _i < keys_2.length; _i++) {
                var key = keys_2[_i];
                var item = data[key];
                doc.setValue(key, item);
            }
            this.android.save(doc);
        }
    };
    Couchbase.prototype.deleteDocument = function (documentId) {
        var doc = this.android.getDocument(documentId);
        return this.android.delete(doc);
    };
    Couchbase.prototype.destroyDatabase = function () {
        this.android.delete();
    };
    Couchbase.prototype.query = function (select) {
        return null;
    };
    Couchbase.prototype.createPullReplication = function (remoteUrl, username, password) {
        var uri = new com.couchbase.lite.URLEndpoint(new java.net.URI(remoteUrl));
        var repConfig = new com.couchbase.lite.ReplicatorConfiguration(this.android, uri);
        repConfig.setReplicatorType(com.couchbase.lite.ReplicatorConfiguration.ReplicatorType.PULL);
        if (username && password) {
            repConfig.setAuthenticator(new com.couchbase.lite.BasicAuthenticator(username, password));
        }
        var replicator = new com.couchbase.lite.Replicator(repConfig);
        return new Replicator(replicator);
    };
    Couchbase.prototype.createPushReplication = function (remoteUrl, username, password) {
        var uri = new com.couchbase.lite.URLEndpoint(new java.net.URI(remoteUrl));
        var repConfig = new com.couchbase.lite.ReplicatorConfiguration(this.android, uri);
        repConfig.setReplicatorType(com.couchbase.lite.ReplicatorConfiguration.ReplicatorType.PUSH);
        if (username && password) {
            repConfig.setAuthenticator(new com.couchbase.lite.BasicAuthenticator(username, password));
        }
        var replicator = new com.couchbase.lite.Replicator(repConfig);
        return new Replicator(replicator);
    };
    Couchbase.prototype.addDatabaseChangeListener = function (callback) {
        this.android.addChangeListener(new com.couchbase.lite.DatabaseChangeListener({
            changed: function (changes) {
                if (callback && typeof callback === 'function') {
                    var ids = [];
                    var documentIds = changes.getDocumentIDs();
                    var size = documentIds.size();
                    for (var i = 0; i < size; i++) {
                        var item = documentIds[i];
                        ids.push(item);
                    }
                    callback(ids);
                }
            }
        }));
    };
    return Couchbase;
}(couchbase_plugin_common_1.Common));
exports.Couchbase = Couchbase;
var Replicator = (function (_super) {
    __extends(Replicator, _super);
    function Replicator(replicator) {
        return _super.call(this, replicator) || this;
    }
    Replicator.prototype.start = function () {
        this.replicator.start();
    };
    Replicator.prototype.stop = function () {
        this.replicator.stop();
    };
    Replicator.prototype.isRunning = function () {
        return (this.replicator.getStatus().getActivityLevel() ===
            com.couchbase.lite.AbstractReplicator.ActivityLevel.BUSY);
    };
    Replicator.prototype.setContinuous = function (isContinuous) {
        this.replicator.getConfig().setContinuous(isContinuous);
    };
    return Replicator;
}(couchbase_plugin_common_1.ReplicatorBase));
exports.Replicator = Replicator;
//# sourceMappingURL=couchbase-plugin.android.js.map