"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var couchbase_plugin_common_1 = require("./couchbase-plugin.common");
var Couchbase = (function (_super) {
    __extends(Couchbase, _super);
    function Couchbase(databaseName) {
        var _this = _super.call(this, databaseName) || this;
        _this.ios = CBLDatabase.alloc().initWithNameError(databaseName);
        return _this;
    }
    Couchbase.prototype.query = function (select) {
        return null;
    };
    Couchbase.prototype.createDocument = function (data, documentId) {
        var doc;
        if (documentId) {
            CBLMutableDocument.alloc().initWithID(documentId);
        }
        else {
            CBLMutableDocument.alloc().init();
        }
        var keys = Object.keys(data);
        for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
            var key = keys_1[_i];
            var item = data[key];
            doc.setValueForKey(key, item);
        }
        this.ios.saveDocumentError(doc);
        return doc.id;
    };
    Couchbase.prototype.getDocument = function (documentId) {
        var doc = this.ios.documentWithID(documentId);
        if (doc) {
            var obj = {};
            var keys = doc.keys;
            var size = keys.count;
            for (var i = 0; i < size; i++) {
                var key = keys.objectAtIndex(i);
                var value = doc.valueForKey(key);
                var newValue = {};
                newValue[key] = value;
                obj = Object.assign(obj, newValue);
            }
            return obj;
        }
        return null;
    };
    Couchbase.prototype.updateDocument = function (documentId, data) {
        var original = this.ios.documentWithID(documentId);
        var newDoc = original.toMutable();
        var keys = Object.keys(data);
        for (var _i = 0, keys_2 = keys; _i < keys_2.length; _i++) {
            var key = keys_2[_i];
            var item = data[key];
            newDoc.setValueForKey(key, item);
        }
        this.ios.saveDocumentError(newDoc);
    };
    Couchbase.prototype.deleteDocument = function (documentId) {
        var doc = this.ios.documentWithID(documentId);
        return this.ios.deleteDocumentError(doc);
    };
    Couchbase.prototype.destroyDatabase = function () {
        return this.ios.delete();
    };
    Couchbase.prototype.createPullReplication = function (remoteUrl, username, password) {
        var url = NSURL.alloc().initWithString(remoteUrl);
        var targetEndpoint = CBLURLEndpoint.alloc().initWithURL(url);
        var replConfig = CBLReplicatorConfiguration.alloc().initWithDatabaseTarget(this.ios, targetEndpoint);
        replConfig.replicatorType = 2;
        if (username && password) {
            replConfig.authenticator = CBLBasicAuthenticator.alloc().initWithUsernamePassword(username, password);
        }
        var replicator = CBLReplicator.alloc().initWithConfig(replConfig);
        return new Replicator(replicator);
    };
    Couchbase.prototype.createPushReplication = function (remoteUrl, username, password) {
        var url = NSURL.alloc().initWithString(remoteUrl);
        var targetEndpoint = CBLURLEndpoint.alloc().initWithURL(url);
        var replConfig = CBLReplicatorConfiguration.alloc().initWithDatabaseTarget(this.ios, targetEndpoint);
        replConfig.replicatorType = 1;
        if (username && password) {
            replConfig.authenticator = CBLBasicAuthenticator.alloc().initWithUsernamePassword(username, password);
        }
        var replicator = CBLReplicator.alloc().initWithConfig(replConfig);
        return new Replicator(replicator);
    };
    Couchbase.prototype.addDatabaseChangeListener = function (callback) {
        this.ios.addChangeListener(function (change) {
            if (callback && typeof callback === 'function') {
                var ids = [];
                var documentIds = change.documentIDs;
                var size = documentIds.count;
                for (var i = 0; i < size; i++) {
                    var item = documentIds[i];
                    ids.push(item);
                }
                callback(ids);
            }
        });
    };
    return Couchbase;
}(couchbase_plugin_common_1.Common));
exports.Couchbase = Couchbase;
var Replicator = (function (_super) {
    __extends(Replicator, _super);
    function Replicator(replicator) {
        return _super.call(this, replicator) || this;
    }
    Replicator.prototype.start = function () {
        this.replicator.start();
    };
    Replicator.prototype.stop = function () {
        this.replicator.stop();
    };
    Replicator.prototype.isRunning = function () {
        return (this.replicator.status.activity ===
            4);
    };
    Replicator.prototype.setContinuous = function (isContinuous) {
        this.replicator.config.continuous = isContinuous;
    };
    return Replicator;
}(couchbase_plugin_common_1.ReplicatorBase));
exports.Replicator = Replicator;
//# sourceMappingURL=couchbase-plugin.ios.js.map